"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ChildTasksCleanup = void 0;
var _tasks = require("@webiny/tasks");
/**
 * Cleanup of the child tasks.
 * This code will remove all the child tasks and their logs, which have no errors in them.
 */
class ChildTasksCleanup {
  async execute(params) {
    const {
      context,
      task
    } = params;
    const {
      items: childTasks
    } = await context.tasks.listTasks({
      where: {
        parentId: task.id
      },
      // Really doubtful there will be more than 10k of child tasks.
      limit: 10000
    });
    if (childTasks.length === 0) {
      return;
    }
    const childTaskIdList = childTasks.map(childTask => childTask.id);
    const {
      items: childLogs
    } = await context.tasks.listLogs({
      where: {
        task_in: childTaskIdList
      },
      limit: 10000
    });
    const deletedChildTaskLogIdList = [];
    /**
     * First, we need to remove all the logs which have no errors.
     */
    for (const log of childLogs) {
      if (log.items.some(item => item.type === _tasks.ITaskLogItemType.ERROR)) {
        continue;
      }
      await context.tasks.deleteLog(log.id);
      if (deletedChildTaskLogIdList.includes(log.task)) {
        continue;
      }
      deletedChildTaskLogIdList.push(log.task);
    }
    /**
     * Now we can remove the tasks.
     */
    for (const childTaskId of deletedChildTaskLogIdList) {
      await context.tasks.deleteTask(childTaskId);
    }
  }
}
exports.ChildTasksCleanup = ChildTasksCleanup;

//# sourceMappingURL=ChildTasksCleanup.js.map